@@ -500,7 +500,7 @@ class SelectLessonFileDialog(LessonFileDialogCommon):
             False, self.update_filelist)
         self.vbox.pack_start(g_show_used, False)
         self.vbox.reorder_child(g_show_used, 0)
-    def update_filelist(self):
+    def update_filelist(self, w=None):
         self.g_liststore.clear()
         if cfg.get_bool('SelectLessonFileDialog/show_used_files'):
             lesson_id_list = [i for i in list(self.m_app.lessonfile_manager.iterate_lesson_ids()) if i not in self.m_tree.get(self.m_cur_menu_path).children]
@@ -518,7 +518,7 @@ class DepsLessonFileDialog(LessonFileDialogCommon):
         """
         LessonFileDialogCommon.__init__(self, app, tree, path)
         self.update_filelist()
-    def update_filelist(self):
+    def update_filelist(self, w=None):
         self.g_liststore.clear()
         for lesson_id in list(self.m_tree.iterate_possible_deps_for(self.m_cur_menu_path)):
             d = self.m_app.lessonfile_manager.m_uiddb[lesson_id]
