@@ -80,7 +80,7 @@ class ReportBugWindow(gtk.Dialog):
         self.g_tw.set_border_width(10)
         # translators, please notice that the word NO_DESCRIPTION must not be
         # translated in this string.
-        self.g_tw.get_buffer().insert_at_cursor(_("""Describe as exactly as you can what you did when this error occoured. If you give no description at all, you make it very difficult to track down this bug. You should replace this text with your description, and also remove the "bug-tag" in the bottom of this text so that this bug is not automatically sorted among the bug reports with no description.\n\n(bug-tag: NO_DESCRIPTION)"""))
+        self.g_tw.get_buffer().insert_at_cursor(_("""Describe as exactly as you can what you did when this error occurred. If you give no description at all, you make it very difficult to track down this bug. You should replace this text with your description, and also remove the "bug-tag" in the bottom of this text so that this bug is not automatically sorted among the bug reports with no description.\n\n(bug-tag: NO_DESCRIPTION)"""))
         label.set_mnemonic_widget(self.g_tw)
         self.vbox.pack_start(self.g_tw)
         self.show_all()
