@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 from __future__ import division
 import gtk, gnome.ui, gobject
@@ -47,7 +47,7 @@ class Teacher(abstract.LessonbasedTeacher):
     ERR_PICKY = 1
     ERR_NO_ELEMS = 2
     def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
     def new_question(self):
         """returns:
